# Food Parser
Useful tools to parse food entries from users.

# Description

It consists of one main modules:

- `foodparser`: tools to work with food logging parsing

# Installation

## Normal installation

```bash
pip install foodparser
```

## Development installation

```bash
git clone https://github.com/JoeyHou/food_parser.git
cd food_parser
pip install --editable .
```
